@@ -283,6 +283,8 @@ class FPL:
         if not include_summary:
             if player_ids:
                 players = [player for player in players.values() if player["id"] in player_ids]
+            else:
+                players = players.values()
 
             if not return_json:
                 players = [Player(player, self.session) for player in players]
